Fitting benchmarks
===================


Benchmarks with :math:`\mathrm{WSe}_2`
#######################################


Photoemission band mapping data for tungsten diselenide (:math:`\mathrm{WSe}_2`).